TarEntryType

Enum TarEntryType 

pub enum TarEntryType {
    Regular,
    Directory,
    Symlink,
    Hardlink,
    BlockDevice,
    CharacterDevice,
    Fifo,
    GlobalExtendedHeader,
    ExtendedHeader,
    Unknown,
}
Tar entry type labels.

Variants



Regular

Regular file entry.



Directory

Directory entry.

Symbolic link entry.

Hard link entry.



BlockDevice

Block device entry.



CharacterDevice

Character device entry.



Fifo

FIFO entry.



GlobalExtendedHeader

Global extended header entry.



ExtendedHeader

Extended header entry.



Unknown

Unknown or unsupported tar entry type.

Implementations

Source

impl TarEntryType

pub const fn as_str(self) -> &'static str

Returns a stable lowercase label.

pub const fn from_typeflag(typeflag: u8) -> TarEntryType

Maps a raw tar typeflag byte to a label.

pub const fn typeflag(self) -> Option<u8>

Returns the standard tar typeflag byte when one is available.